@@ -1,7 +1,7 @@
 // C++ source
 // This file is part of RGL.
 //
-// $Id: fps.cpp 586 2007-08-03 19:47:16Z dmurdoch $
+// $Id: fps.cpp 666 2008-04-17 13:44:58Z dmurdoch $
 
 #include "fps.h"
 
@@ -34,7 +34,8 @@ void FPS::render(double t, RenderContext* ctx)
   glColor3f(1.0f,1.0f,1.0f);
   glRasterPos2f( 1.0f, -0.9f);
 
-  ctx->font->enable();
-  ctx->font->draw(buffer, strlen(buffer), -1, 0);
+  if (ctx->font)
+    ctx->font->draw(buffer, strlen(buffer), -1, 0.0, *ctx);
+
   framecnt++;
 }
