@@ -1,7 +1,7 @@
 // C++ source
 // This file is part of RGL.
 //
-// $Id: rglview.cpp 590 2007-08-07 00:02:51Z dmurdoch $
+// $Id: rglview.cpp 666 2008-04-17 13:44:58Z dmurdoch $
 
 #include "rglview.h"
 #include "opengl.hpp"
@@ -64,7 +64,15 @@ void RGLView::hide()
 
 void RGLView::setWindowImpl(WindowImpl* impl) {
   View::setWindowImpl(impl);
-  renderContext.font = &impl->font;
+//
+// Currently the FreeType font handling in AGL on the Mac is too poor to be worth 
+// using, so default to not using it.
+//
+#if defined HAVE_FREETYPE
+  renderContext.font = impl->getFont("sans", 1, 1, true);
+#else
+  renderContext.font = impl->fonts[0];
+#endif
 }
 
 Scene* RGLView::getScene() {
@@ -646,6 +654,56 @@ void RGLView::setScale(double* src)
 	View::update();
 }
 
+void RGLView::setDefaultFont(const char* family, int style, double cex, bool useFreeType)
+{
+  renderContext.font = View::windowImpl->getFont(family, style, cex, useFreeType);
+}
+  
+const char* RGLView::getFontFamily() const 
+{
+  return renderContext.font->family;
+}
+
+void RGLView::setFontFamily(const char *family)
+{
+  setDefaultFont(family, getFontStyle(), getFontCex(), getFontUseFreeType());
+}
+
+int RGLView::getFontStyle() const 
+{
+  return renderContext.font->style;
+}
+
+void RGLView::setFontStyle(int style)
+{
+  setDefaultFont(getFontFamily(), style, getFontCex(), getFontUseFreeType());
+}
+
+double RGLView::getFontCex() const 
+{
+  return renderContext.font->cex;
+}
+
+void RGLView::setFontCex(double cex)
+{
+  setDefaultFont(getFontFamily(), getFontStyle(), cex, getFontUseFreeType());
+}
+
+const char* RGLView::getFontname() const 
+{
+  return renderContext.font->fontname;
+}
+
+bool RGLView::getFontUseFreeType() const
+{
+  return renderContext.font->useFreeType;
+}
+
+void RGLView::setFontUseFreeType(bool useFreeType)
+{
+  setDefaultFont(getFontFamily(), getFontStyle(), getFontCex(), useFreeType);
+}
+
 void RGLView::getPosition(double* dest)
 {    
     Viewpoint* viewpoint = scene->getViewpoint();
