@@ -2,12 +2,12 @@
 #ifdef RGL_W32
 // ---------------------------------------------------------------------------
 // W32 Library Implementation
-// $Id: win32lib.cpp 592 2007-08-13 19:52:09Z dmurdoch $
+// $Id: win32lib.cpp 611 2007-11-10 17:22:02Z dmurdoch $
 // ---------------------------------------------------------------------------
 #include "lib.hpp"
 #include "win32gui.hpp"
 #include <windows.h>
-#include <cassert>
+#include "assert.hpp"
 // ---------------------------------------------------------------------------
 namespace lib {
 // ---------------------------------------------------------------------------
